@@ -111,6 +111,7 @@ Ext.define('MP.data.MetaData', {
                     var res = r.responseText && Ext.decode(r.responseText);
                     if(res) {
                         Ext.MessageBox.alert(
+                            // TRANSLATORS: {0} is the error code, {1} the error message
                             Ext.String.format(_('Communication error ({0} {1})'),
                                               r.status, r.statusText),
                             res.message);
@@ -127,11 +128,17 @@ Ext.define('MP.data.MetaData', {
             return (value===true) ? _('Yes') : _('No');
         },
 
-        renderDate: Ext.util.Format.dateRenderer(_('m/d/Y')),
+        renderDate: function(value) {
+            return Ext.util.Format.date(value, _('m/d/Y'));
+        },
 
-        renderTime: Ext.util.Format.dateRenderer(_('g:i A')),
+        renderTime: function(value) {
+            return Ext.util.Format.date(value, _('g:i A'));
+        },
 
-        renderTimestamp: Ext.util.Format.dateRenderer(_('m/d/Y g:i:s A'))
+        renderTimestamp: function(value) {
+            return Ext.util.Format.date(value, _('m/d/Y g:i:s A'));
+        }
     },
 
     // Regexp used to recognize fields coming from the DB, to be
